@@ -142,20 +142,10 @@ module Bio
   autoload :Newick,         'bio/db/newick'
   autoload :Nexus,          'bio/db/nexus'
 
-  autoload :PhyloXML,       'bio/db/phyloxml/phyloxml_elements'
-  # Bio::Taxonomy will be moved to other file
-  autoload :Taxonomy,       'bio/db/phyloxml/phyloxml_elements'
-  ## below are described in bio/db/phyloxml/phyloxml_elements.rb
-  #module PhyloXML
-  #  autoload :Parser,       'bio/db/phyloxml/phyloxml_parser'
-  #  autoload :Writer,       'bio/db/phyloxml/phyloxml_writer'
-  #end
-
   ### IO interface modules
 
   autoload :Registry,       'bio/io/registry'
   autoload :Fetch,          'bio/io/fetch'
-  autoload :SQL,            'bio/io/sql'
   autoload :FlatFile,       'bio/io/flatfile'
   autoload :FlatFileIndex,  'bio/io/flatfile/index' # chage to FlatFile::Index ?
   ## below are described in bio/io/flatfile/index.rb
